#include "vrsapi.h"

#include <stdio.h>
#include <string.h>

const char* szUsage =
     "VRSCMD (C) NCH Swift Sound\r\n"
     "\r\n"
     "This is a command line tool to control the VRS Recording System from the command line. "
     "For more information about the VRS Recording System (including software download), please see "
     "www.nch.com.au/vrs.\r\n"
     "\r\n"
     "The VRS Recording System must be installed on the computer before this is used. "
     "All channels must be set to manual mode (refer to the VRS Settings).\r\n"
     "\r\n"
     "USAGE:\r\n"
     "    vrscmd.exe CommandList\r\n"
     "\r\n"
     "  CommandList is a list of any number of the following...\r\n"
     "\r\n"
     "    -start ZeroBasedChannelID\r\n"
     "        starts recording on the specified channel\r\n"
     "    -stop ZeroBasedChannelID\r\n"
     "        stop recording on the specified channel\r\n"
     "    -start ZeroBasedChannelID \"FullRecordingWavFilePath\"\r\n"
     "        starts recording with the wav file path\r\n"
     "    -data ZeroBasedChannelID \"RecordingData\"\r\n"
     "        sets the recording text data for that channel\r\n"
     "        data is cleared when recording ends\r\n"
     "    -datapersist ZeroBasedChannelID \"RecordingData\"\r\n"
     "        sets the recording text data for that channel\r\n"
     "        data is not cleared when recording ends\r\n"
     "\r\n"
     "Notes:\r\n"
     "1. All channel numbers start from 0.\r\n"
     "2. Any number of commands can be run from the same line.\r\n"
     "\r\n"
     "Examples:\r\n"
     "   vrscmd.exe -start 0 -start 1 -start 2 -start 3\r\n"
     "      starts channels 1 - 4\r\n"
     "   vrscmd.exe -stop 0\r\n"
     "      stops channel 1\r\n"
     "   vrscmd.exe -start 0 -data \"MyRecording\"\r\n"
     "      starts recording on channel 1\r\n"
     "      data MyRecording will be logged with the recording\r\n"
      ;


int main(int argc, char* argv[])
{
   // If we don't have enough arguments print out the usage text
   if (argc < 2) {
     printf(szUsage);
     return 1;
   }

   int iCurrentArgument = 1;

   while (iCurrentArgument < argc) {

     if (strcmp(argv[iCurrentArgument], "-start") == 0){

       iCurrentArgument++;

       int nChannelZeroBased = 0;
       const char* szFullPathToWaveFile = NULL;

       if (iCurrentArgument < argc) {
         if (argv[iCurrentArgument][0] != '-') {
           nChannelZeroBased = atoi(argv[iCurrentArgument]);
           iCurrentArgument++;
         }
       }

       if (iCurrentArgument < argc) {
         if (argv[iCurrentArgument][0] != '-') {
           szFullPathToWaveFile = argv[iCurrentArgument];
           iCurrentArgument++;
         }
       }

       if (szFullPathToWaveFile != NULL) VRSAPIStartRecorder(nChannelZeroBased, szFullPathToWaveFile);
       else VRSAPIStartRecorder(nChannelZeroBased);

       continue;

     }

     if (strcmp(argv[iCurrentArgument], "-stop") == 0){

       iCurrentArgument++;

       int nChannelZeroBased = 0;

       if (iCurrentArgument < argc) {
         if (argv[iCurrentArgument][0] != '-') {
           nChannelZeroBased = atoi(argv[iCurrentArgument]);
           iCurrentArgument++;
         }
       }

       VRSAPIStopRecorder(nChannelZeroBased);

       continue;

     }

     if (strcmp(argv[iCurrentArgument], "-data") == 0){

       iCurrentArgument++;

       int nChannelZeroBased = 0;
       const char* szFullPathToWaveFile = "";

       if (iCurrentArgument < argc) {
         if (argv[iCurrentArgument][0] != '-') {
           nChannelZeroBased = atoi(argv[iCurrentArgument]);
           iCurrentArgument++;
         }
       }

       if (iCurrentArgument < argc) {
         if (argv[iCurrentArgument][0] != '-') {
           szFullPathToWaveFile = argv[iCurrentArgument];
           iCurrentArgument++;
         }
       }

       VRSAPISetRecordingData(nChannelZeroBased, szFullPathToWaveFile, false);

       continue;

     }

     if (strcmp(argv[iCurrentArgument], "-datapersist") == 0){

       iCurrentArgument++;

       int nChannelZeroBased = 0;
       const char* szFullPathToWaveFile = "";

       if (iCurrentArgument < argc) {
         if (argv[iCurrentArgument][0] != '-') {
           nChannelZeroBased = atoi(argv[iCurrentArgument]);
           iCurrentArgument++;
         }
       }

       if (iCurrentArgument < argc) {
         if (argv[iCurrentArgument][0] != '-') {
           szFullPathToWaveFile = argv[iCurrentArgument];
           iCurrentArgument++;
         }
       }

       VRSAPISetRecordingData(nChannelZeroBased, szFullPathToWaveFile, true);

       continue;

     }

     // If we get to here we know an invalid argument was used
     printf("ERROR (Invalid Argument): %s\r\n"
            "Run vrscmd.exe without arguments to view help.\r\n"
     				, argv[iCurrentArgument]);
     return 1;

   } //while loop

   return 0;
}
